@@ -135,6 +135,17 @@ def meta_from_soup_row(team, soup_row):
         last_name, first_name = name, ''
     else:
         last_name, first_name = map(lambda s: s.strip(), name.split(','))
+
+    # Format the player's height into inches. If we can't parse the data,
+    # defaul height to 0
+    feet, inches = 0, 0
+    pieces = re.findall('[0-9]+', data[4])
+    if len(pieces) >= 1:
+        feet = try_int(pieces[0])
+        if len(pieces) >= 2:
+            inches = try_int(pieces[1])
+    height = feet * 12 + inches
+
     return {
         'team': team,
         'profile_id': profile_id_from_url(profile_url),
@@ -145,7 +156,7 @@ def meta_from_soup_row(team, soup_row):
         'full_name': '%s %s' % (first_name, last_name),
         'position': data[2],
         'status': data[3],
-        'height': data[4],
+        'height': height,
         'weight': data[5],
         'birthdate': data[6],
         'years_pro': try_int(data[7]),
